<template>
  <div style="width: 100%">
    <el-card class="box-card">
      <div slot="header" class="clearfix">
        <span style="font-weight: 600; font-size: 20px">项目工作单统计</span>
        <div class="card-title-right">
          <div :style="{ color: weekFlag ? '#378cff' : '' }" @click="changeDate(1)">近7天</div>
          <div :style="{ color: monthFlag ? '#378cff' : '' }" style="margin: 0 30px 0 10px" @click="changeDate(2)">
            近30天
          </div>
          <el-date-picker
            v-model="value2"
            type="daterange"
            :picker-options="pickerOptions"
            range-separator="至"
            start-placeholder="开始日期"
            end-placeholder="结束日期"
            align="right"
            value-format="yyyyMMdd"
          />
          <el-button type="primary" style="margin-left: 10px" @click="searchOnClick">搜索</el-button>
        </div>
      </div>
      <div id="main" />
    </el-card>
  </div>
</template>
<script>
import * as echarts from 'echarts';
import * as dash from '@/api/dashboard/dash';

export default {
  name: 'XMGZD',
  props: {
    activeId: {
      type: String,
      default: '',
    },
  },
  data() {
    return {
      pickerOptions: {
        shortcuts: [
          {
            text: '最近一周',
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
              picker.$emit('pick', [start, end]);
            },
          },
          {
            text: '最近一个月',
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
              picker.$emit('pick', [start, end]);
            },
          },
          {
            text: '最近三个月',
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
              picker.$emit('pick', [start, end]);
            },
          },
        ],
      },
      value2: '',
      myChart: null,
      weekFlag: 1, // 近七天
      monthFlag: null, // 近30天
      options: {},
    };
  },
  mounted() {
    this.getCenterLine();
    // 监听屏幕宽度变化：当浏览器发生resize事件的时候，触发echart的resize事件，重绘canvas
    window.addEventListener('resize', () => {
      this.changeWidth();
    });
    this.getProjectInfo();
  },
  created() {},
  methods: {
    changeDate(type) {
      if (type == 1) {
        this.monthFlag = null;
        if (this.weekFlag) {
          this.weekFlag = null;
        } else {
          this.weekFlag = 1;
        }
        if (this.weekFlag) {
          this.monthFlag = null;
          this.value2 = [];
        }
        this.searchByTime();
      }
      if (type == 2) {
        this.weekFlag = null;
        if (this.monthFlag) {
          this.monthFlag = null;
        } else {
          this.monthFlag = 1;
        }
        if (this.monthFlag) {
          this.weekFlag = null;
          this.value2 = [];
        }
        this.searchByTime();
      }
    },
    searchOnClick() {
      this.monthFlag = null;
      this.weekFlag = null;
      this.searchByTime();
    },
    getProjectInfo() {
      //获取项目数据
      dash.getNumByProject().then((res) => {
        if (res) {
          this.projectInfo = res;
          this.options.xAxis[0].data = this.projectInfo.projjectName;
          // 事件数量
          this.options.series[0].data = this.projectInfo.eventNum;
          // 工单数量
          this.options.series[1].data = this.projectInfo.workNum;
          this.myChart.setOption(this.options);
        }
      });
    },
    searchByTime() {
      var param = {};
      if (this.value2 != null && this.value2.length > 0) {
        param.begin = this.value2[0];
        param.end = this.value2[1];
      }

      if (this.weekFlag != null) {
        param.weekFlag = this.weekFlag;
      }
      if (this.monthFlag != null) {
        param.monthFlag = this.monthFlag;
      }
      dash.getNumByProject(param).then((res) => {
        if (res) {
          this.projectInfo = res;
          this.options.xAxis[0].data = this.projectInfo.projjectName;
          // 事件数量
          this.options.series[0].data = this.projectInfo.eventNum;
          // 工单数量
          this.options.series[1].data = this.projectInfo.workNum;
          this.myChart.setOption(this.options);
        }
      });
    },
    getCenterLine() {
      // getCenterLine({
      //   id: this.activeId,
      //   weekFlag: this.weekFlag,
      //   monthFlag: this.monthFlag,
      //   startDay: this.value2 ? this.value2[0] : null,
      //   endDay: this.value2 ? this.value2[1] : null
      // }).then(res => {
      //   const data = res.data
      var chartDom = document.getElementById('main');
      this.myChart = echarts.init(chartDom);
      this.options = {
        color: ['#5EDEA5', '#1877FF'],
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow',
          },
        },
        legend: {
          data: ['问题工单', '事件工单'],
        },
        toolbox: {
          show: true,
          orient: 'vertical',
          left: 'right',
          top: 'center',
          feature: {
            mark: { show: true },
            dataView: { show: true, readOnly: false },
            magicType: { show: true, type: ['line', 'bar', 'stack'] },
            restore: { show: true },
            saveAsImage: { show: true },
          },
        },
        xAxis: [
          {
            type: 'category',
            axisTick: { show: false },
            data: ['预算一体化平台', '一卡通系统', '预算一体化平台', '一卡通系统'],
          },
        ],
        yAxis: [
          {
            type: 'value',
          },
        ],
        series: [
          {
            name: '事件工单',
            type: 'bar',
            barWidth: 20,
            barGap: 0,
            emphasis: {
              focus: 'series',
            },
            data: [320, 332, 301, 334],
          },
          {
            name: '问题工单',
            type: 'bar',
            barWidth: 20,

            emphasis: {
              focus: 'series',
            },
            data: [220, 182, 191, 234],
          },
        ],
      };

      this.options && this.myChart.setOption(this.options);
      // });
    },
    changeWidth() {
      this.myChart.resize();
    },
  },
};
</script>
<style lang="scss" scoped>
#main {
  width: 100%;
  height: 400px;
}

.box-card {
  margin-top: 10px;
  width: 100%;
  border-radius: 10px;
  border: none;

  .card-title-right {
    display: flex;
    align-items: center;
    align-self: flex-end;
    float: right;
  }
}
</style>
